@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 our $VERSION;
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use Net::DNS qw(:DEFAULT);
 use base     qw(Exporter Net::DNS);
@@ -17,10 +17,23 @@ use Socket qw(pack_ip_mreq pack_ipv6_mreq inet_pton
 		IPPROTO_IP IPPROTO_IPV6 IP_MULTICAST_TTL IPV6_MULTICAST_HOPS
 		IP_ADD_MEMBERSHIP IPV6_ADD_MEMBERSHIP IPV6_JOIN_GROUP);
 
-use constant REUSEADDR => Socket->can('SO_REUSEADDR');
-use constant REUSEPORT => Socket->can('SO_REUSEPORT');
-use constant ADDMEMBER => Socket->can('IPV6_ADD_MEMBERSHIP');
-use constant JOINGROUP => Socket->can('IPV6_JOIN_GROUP');
+use constant REUSEPORT => defined eval {
+	my $socket = Net::DNS::Resolver->new->_create_udp_socket('224.0.0.251');
+	$socket->setsockopt( SOL_SOCKET, SO_REUSEPORT, 1 );
+};
+
+use constant ADDMEMBER => defined eval {
+	my $socket6 = Net::DNS::Resolver->new->_create_udp_socket('FF02::FB');
+	my $ip_mreq = pack_ipv6_mreq( inet_pton( AF_INET6, 'FF02::FB' ), 0 );
+	$socket6->setsockopt( IPPROTO_IPV6, IPV6_ADD_MEMBERSHIP, $ip_mreq );
+};
+
+use constant JOINGROUP => defined eval {
+	my $socket6 = Net::DNS::Resolver->new->_create_udp_socket('FF02::FB');
+	my $ip_mreq = pack_ipv6_mreq( inet_pton( AF_INET6, 'FF02::FB' ), 0 );
+	$socket6->setsockopt( IPPROTO_IPV6, IPV6_JOIN_GROUP, $ip_mreq );
+	return undef if ADDMEMBER;
+};
 
 
 =head1 NAME
@@ -86,7 +99,8 @@ sub Net::DNS::Resolver::bgsend {
 	my $port   = $self->port($multicast_port);
 	foreach my $ip ( $self->nameservers(@multicast_group) ) {
 		my $socket = $self->_create_udp_socket($ip);
-		$socket->setsockopt( SOL_SOCKET, SO_REUSEADDR, 1 ) if REUSEADDR;
+		next unless $socket;				# uncoverable branch true
+		$socket->setsockopt( SOL_SOCKET, SO_REUSEADDR, 1 );
 		$socket->setsockopt( SOL_SOCKET, SO_REUSEPORT, 1 ) if REUSEPORT;
 		if ( $socket->sockdomain() == AF_INET6 ) {
 			my $ip_mreq = pack_ipv6_mreq( inet_pton( AF_INET6, $ip ), 0 );
